@@ -1,14 +1,14 @@
-
 from collections import defaultdict
 
+
 class Graph:
     def __init__(self, vertices):
-        self.graph = defaultdict(list) 
-        self.V = vertices 
+        self.graph = defaultdict(list)
+        self.V = vertices
 
     def addEdge(self, u, v):
         self.graph[u].append(v)
- 
+
     def topologicalSortUtil(self, v, visited, stack):
         visited[v] = True
         for i in self.graph[v]:
@@ -17,9 +17,9 @@ class Graph:
         stack.append(v)
 
     def topologicalSort(self):
-        visited = [False]*self.V
+        visited = [False] * self.V
         stack = []
         for i in range(self.V):
             if visited[i] == False:
                 self.topologicalSortUtil(i, visited, stack)
-        return(stack[::-1]) 
\ No newline at end of file
+        return stack[::-1]
